@@ -1,7 +1,6 @@
 from email.policy import default
 from django.db import models
 from django.conf import settings
-from .admin import admin_site
 
 
 
@@ -17,5 +16,3 @@ class AdminApps(models.Model):
     class Meta:
         verbose_name = 'Admin App'
         verbose_name_plural = 'Admin Apps'
-
-admin_site.register(AdminApps)
\ No newline at end of file
